irl\_benchmark.irl.algorithms package
=====================================

Submodules
----------

irl\_benchmark.irl.algorithms.appr\_irl module
----------------------------------------------

.. automodule:: irl_benchmark.irl.algorithms.appr_irl
    :members:
    :undoc-members:
    :show-inheritance:

irl\_benchmark.irl.algorithms.base\_algorithm module
----------------------------------------------------

.. automodule:: irl_benchmark.irl.algorithms.base_algorithm
    :members:
    :undoc-members:
    :show-inheritance:

irl\_benchmark.irl.algorithms.mce\_irl module
---------------------------------------------

.. automodule:: irl_benchmark.irl.algorithms.mce_irl
    :members:
    :undoc-members:
    :show-inheritance:

irl\_benchmark.irl.algorithms.me\_irl module
--------------------------------------------

.. automodule:: irl_benchmark.irl.algorithms.me_irl
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: irl_benchmark.irl.algorithms
    :members:
    :undoc-members:
    :show-inheritance:
